@@ -6,6 +6,7 @@
 #include "common/mime.h"
 #include "common/qt.h"
 #include "common/strings/formatting.h"
+#include "mkvtoolnix-gui/merge/attachment_model.h"
 #include "mkvtoolnix-gui/merge/tab.h"
 #include "mkvtoolnix-gui/merge/tab_p.h"
 #include "mkvtoolnix-gui/forms/merge/tab.h"
@@ -78,29 +79,33 @@ Tab::setupAttachmentsControls() {
   connect(p.removeAllAttachmentsAction,         &QAction::triggered,                                                    this, &Tab::onRemoveAllAttachments);
   connect(p.selectAllAttachmentsAction,         &QAction::triggered,                                                    this, &Tab::onSelectAllAttachments);
 
-  connect(p.enableAllAttachedFilesAction,       &QAction::triggered,                                                    this, [=]() { enableDisableAllAttachedFiles(true); });
-  connect(p.disableAllAttachedFilesAction,      &QAction::triggered,                                                    this, [=]() { enableDisableAllAttachedFiles(false); });
-  connect(p.enableSelectedAttachedFilesAction,  &QAction::triggered,                                                    this, [=]() { enableDisableSelectedAttachedFiles(true); });
-  connect(p.disableSelectedAttachedFilesAction, &QAction::triggered,                                                    this, [=]() { enableDisableSelectedAttachedFiles(false); });
+  connect(p.enableAllAttachedFilesAction,       &QAction::triggered,                                                    this, [this]() { enableDisableAllAttachedFiles(true); });
+  connect(p.disableAllAttachedFilesAction,      &QAction::triggered,                                                    this, [this]() { enableDisableAllAttachedFiles(false); });
+  connect(p.enableSelectedAttachedFilesAction,  &QAction::triggered,                                                    this, [this]() { enableDisableSelectedAttachedFiles(true); });
+  connect(p.disableSelectedAttachedFilesAction, &QAction::triggered,                                                    this, [this]() { enableDisableSelectedAttachedFiles(false); });
 
-  connect(p.ui->attachmentDescription,            &QLineEdit::textChanged,                                                this, &Tab::onAttachmentDescriptionChanged);
-  connect(p.ui->attachmentMIMEType,               &QComboBox::currentTextChanged,                                         this, &Tab::onAttachmentMIMETypeChanged);
-  connect(p.ui->attachmentMIMEType,               &QComboBox::editTextChanged,                                            this, &Tab::onAttachmentMIMETypeChanged);
-  connect(p.ui->attachmentName,                   &QLineEdit::textChanged,                                                this, &Tab::onAttachmentNameChanged);
-  connect(p.ui->attachmentStyle,                  static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &Tab::onAttachmentStyleChanged);
-  connect(p.ui->attachments,                      &Util::BasicTreeView::ctrlDownPressed,                                  this, &Tab::onMoveAttachmentsDown);
-  connect(p.ui->attachments,                      &Util::BasicTreeView::ctrlUpPressed,                                    this, &Tab::onMoveAttachmentsUp);
-  connect(p.ui->attachments,                      &Util::BasicTreeView::customContextMenuRequested,                       this, &Tab::showAttachmentsContextMenu);
-  connect(p.ui->attachments,                      &Util::BasicTreeView::deletePressed,                                    this, &Tab::onRemoveAttachments);
-  connect(p.ui->attachments,                      &Util::BasicTreeView::insertPressed,                                    this, &Tab::onAddAttachments);
-  connect(p.ui->attachments->selectionModel(),    &QItemSelectionModel::selectionChanged,                                 this, &Tab::onAttachmentSelectionChanged);
-  connect(p.ui->attachmentsTab,                   &Util::FilesDragDropWidget::filesDropped,                               this, &Tab::addAttachments);
-  connect(p.ui->moveAttachmentsDown,              &QPushButton::clicked,                                                  this, &Tab::onMoveAttachmentsDown);
-  connect(p.ui->moveAttachmentsUp,                &QPushButton::clicked,                                                  this, &Tab::onMoveAttachmentsUp);
-  connect(p.ui->attachedFiles,                    &Util::BasicTreeView::doubleClicked,                                    this, &Tab::toggleMuxThisForSelectedAttachedFiles);
-  connect(p.ui->attachedFiles,                    &Util::BasicTreeView::allSelectedActivated,                             this, &Tab::toggleMuxThisForSelectedAttachedFiles);
-  connect(p.ui->attachedFiles,                    &Util::BasicTreeView::customContextMenuRequested,                       this, &Tab::showAttachedFilesContextMenu);
+  connect(p.ui->attachmentDescription,          &QLineEdit::textChanged,                                                this, &Tab::onAttachmentDescriptionChanged);
+  connect(p.ui->attachmentMIMEType,             &QComboBox::currentTextChanged,                                         this, &Tab::onAttachmentMIMETypeChanged);
+  connect(p.ui->attachmentMIMEType,             &QComboBox::editTextChanged,                                            this, &Tab::onAttachmentMIMETypeChanged);
+  connect(p.ui->attachmentName,                 &QLineEdit::textChanged,                                                this, &Tab::onAttachmentNameChanged);
+  connect(p.ui->attachmentStyle,                static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &Tab::onAttachmentStyleChanged);
+  connect(p.ui->attachments,                    &Util::BasicTreeView::ctrlDownPressed,                                  this, &Tab::onMoveAttachmentsDown);
+  connect(p.ui->attachments,                    &Util::BasicTreeView::ctrlUpPressed,                                    this, &Tab::onMoveAttachmentsUp);
+  connect(p.ui->attachments,                    &Util::BasicTreeView::customContextMenuRequested,                       this, &Tab::showAttachmentsContextMenu);
+  connect(p.ui->attachments,                    &Util::BasicTreeView::deletePressed,                                    this, &Tab::onRemoveAttachments);
+  connect(p.ui->attachments,                    &Util::BasicTreeView::insertPressed,                                    this, &Tab::onAddAttachments);
+  connect(p.ui->attachments->selectionModel(),  &QItemSelectionModel::selectionChanged,                                 this, &Tab::onAttachmentSelectionChanged);
+  connect(p.ui->attachmentsTab,                 &Util::FilesDragDropWidget::filesDropped,                               this, &Tab::addAttachments);
+  connect(p.ui->moveAttachmentsDown,            &QPushButton::clicked,                                                  this, &Tab::onMoveAttachmentsDown);
+  connect(p.ui->moveAttachmentsUp,              &QPushButton::clicked,                                                  this, &Tab::onMoveAttachmentsUp);
+  connect(p.ui->attachedFiles,                  &Util::BasicTreeView::doubleClicked,                                    this, &Tab::toggleMuxThisForSelectedAttachedFiles);
+  connect(p.ui->attachedFiles,                  &Util::BasicTreeView::allSelectedActivated,                             this, &Tab::toggleMuxThisForSelectedAttachedFiles);
+  connect(p.ui->attachedFiles,                  &Util::BasicTreeView::customContextMenuRequested,                       this, &Tab::showAttachedFilesContextMenu);
   connect(p.attachedFilesModel,                 &AttachedFileModel::itemChanged,                                        this, &Tab::attachedFileItemChanged);
+  connect(p.attachedFilesModel,                 &QStandardItemModel::rowsInserted,                                      this, &Tab::updateAttachmentsTabTitle);
+  connect(p.attachedFilesModel,                 &QStandardItemModel::rowsRemoved,                                       this, &Tab::updateAttachmentsTabTitle);
+  connect(p.attachmentsModel,                   &QStandardItemModel::rowsInserted,                                      this, &Tab::updateAttachmentsTabTitle);
+  connect(p.attachmentsModel,                   &QStandardItemModel::rowsRemoved,                                       this, &Tab::updateAttachmentsTabTitle);
 
   onAttachmentSelectionChanged();
 
@@ -596,4 +601,12 @@ Tab::addAttachmentsFromIdentifiedBluray(mtx::bluray::disc_library::info_t const
   p_func()->attachmentsModel->addAttachments(QList<AttachmentPtr>{} << attachment);
 }
 
+void
+Tab::updateAttachmentsTabTitle() {
+  auto &p             = *p_func();
+  auto numAttachments = p.attachedFilesModel->rowCount() + p.attachmentsModel->rowCount();
+
+  p.ui->tabs->setTabText(2, Q("%1 (%2)").arg(QY("Attachments")).arg(numAttachments));
+}
+
 }
